export LC_ALL='C.UTF-8'
export TZ='UTC'
export TMPDIR='' # changed during 07initialization.bash
DO_NOT_INFORM_TO_STDOUT=0
function inform {
    if ((!$DO_NOT_INFORM_TO_STDOUT)); then
        echo "$SCRIPTNAME:" $@;
    fi;
}
function inform_stderr { echo >&2 "$SCRIPTNAME:" $@; }
function warn { echo >&2 "$SCRIPTNAME warning:" $@; exit 1; }
function die { echo >&2 "$SCRIPTNAME error:" $@; exit 1; }
. "$RC_DIR/$SCRIPTNAME.conf"
function print_bar {
    echo '-------------------------------------------------------------------------------'
}
function die_if_empty {
    for A in "$@"; do
        [ -z "$A" ] && die "the empty string '' is"\
        "unacceptable in this context"
    done
    true
}
function die_if_spaces {
    for A in "$@"; do
        [[ "$A" = *[[:space:]]* ]] && die "unable to handle"\
        "the space or spaces in '$A'"
    done
    true
}
# The 'z' in 'die_if_zsp' is for zero-length; that is, empty.
# The 'sp' is for spaces, so the name may be read
# as "die if is empty or has spaces".
function die_if_zsp { die_if_empty "$@"; die_if_spaces "$@"; }
function are_legal_filepaths {
    for A in "$@"; do
        echo "$A" | sed -rn\
        -e '\%^$%q1;:a;'\
        -e 's%^([[:alnum:]_][[:alnum:]_.~+-]*|\.{0,2})(.*)$%\2%;'\
        -e '\%^$%d;\%^/%!q1;s%^/%%;ba;'\
        || return 1;
    done
    return 0;
}
function are_legal_filenames {
    for A in "$@"; do
        echo "$A" | sed -rne '\%^[[:alnum:]_][[:alnum:]_.~+-]*$%!q1'\
        || return 1;
    done
    return 0;
}
# (The next is a helper for the two functions that follow it.)
function help_require_to_die {
cat <<END >&2
$SCRIPTNAME error: unconventional names like "$*" are not supported

Historically, Unix systems required filenames, pathnames and the like
to adhere to a certain format.  Debian's convention has relaxed the
format to some degree, but to function reliably, this program still
requires that the relaxed format be respected:

    * no spaces
    * no control characters
    * no other punctuation than the five characters [_.~+-]
    * no ordinary words that begin with any of the four
      characters [.~+-] because words that begin with these are
      likely to be reserved for special purposes
    * however, in filepaths, the specials "." and ".." are allowed

(For information, Debian's convention also requires ascii in certain
circumstances, but this program does not require that.)
END
exit 1
}
function require_filepaths_to_be_legal {
    are_legal_filepaths "$@" || help_require_to_die "$*"
}
function require_filenames_to_be_legal {
    are_legal_filepaths "$@" || help_require_to_die "$*"
}
function handle_exit_trap {
    if [ -n "$TMPDIR" ]; then
        if (($LEAVE_TEMP_DATA_BEHIND)); then
            inform_stderr "finishing (or exiting), but leaving behind"\
            "temporary data files for the user's inspection in $TMPDIR/"
        else
            rm -rf "$TMPDIR"
        fi
    fi
}
trap handle_exit_trap EXIT

